# ejcli

A testing system console client.

# Installation

To install ejcli, simply type `pip3 install ejcli`. You may need to use `sudo`.

# Testing system compatibility

ejcli supports [ejudge](https://ejudge.ru), [PCMS2](https://neerc.ifmo.ru/trains/information/software.html), [informatics.msk.ru](https://informatics.msk.ru/), [codeforces.com](https://codeforces.com), [Google Code Jam](https://codingcompetitions.withgoogle.com/codejam) and [JJS](https://github.com/MikailBag/jjs), to a varying degree of compatibility.
